/*****************************************************************************************
 *
 * config.c
 * Copyright (c) 2010 NuukiaWorld
 *
 *  This file is part of "Morse tone".
 *
 *  "Network database" is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  "Network database" is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with "Morse tone".  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Version    Date          Author             Log
 *  --------------------------------------------------------------------------------------
 *  1.0        04.10.2010    NuukiaWorld        Initial Release
 *
 ****************************************************************************************/

#include "main.h"

/**************************************************************************************/

// Morse code speed preview encoded in 7-bit GSM default alphabet
#define  PACK_7BITS(N,C1,C2)  ((unsigned char)((((C2)<<7)|((C1)&0x7F))>>(N)%7))

#define  PREVIEW_LEN 5
const unsigned char preview_msg[(PREVIEW_LEN*7+7)/8] = {
   PACK_7BITS(0,'N','O'),
   PACK_7BITS(1,'O','K'),
   PACK_7BITS(2,'K','I'),
   PACK_7BITS(3,'I','A'),
   PACK_7BITS(4,'A',0)
};

/**************************************************************************************/

static char *init_wpm_buffer(void) {
   unsigned int wpm, ticks_per_unit;

   ticks_per_unit = own_get_config(confid_ticks_per_unit);
   // Using ( 2 * X + 1 ) / 2 for rounding to nearest
   wpm = ( 2 * (unsigned int)( 60 * TICKS_PER_SECOND / 50 ) / ticks_per_unit + 1 ) / 2;
   ntoa( wpm, (char*)global_buffer );
   return (char*)global_buffer;
}

/**************************************************************************************/

unsigned int config_dispatcher( unsigned int msg ) {
   unsigned int wpm, ticks_per_unit;
   
   switch(msg) {
      case MSG_D_INIT:        // application initialization
         dialog_open( init_wpm_buffer(), &dialog_wpm );
         msg=MSG_R_STAY;
         break;
         
      case MSG_D_QUIT:        // handle application quit
         msg=MSG_R_QUIT;
         break;

      case MSG_DIALOG_ACCEPTED:
         wpm = atoi((char*)global_buffer);
         if( wpm > 150 ) wpm = 150;
         else if( wpm < 5 ) wpm = 5;
         // Using ( 2 * X + 1 ) / 2 for rounding to nearest
         ticks_per_unit = ( 2 * (unsigned int)( 60 * TICKS_PER_SECOND / 50 ) / wpm + 1 ) / 2;
         own_set_config( confid_ticks_per_unit, ticks_per_unit );
         display_msg( DMI_DONE, &str_done );
         
         // Play preview
         if( build_morse_tone( preview_msg, PREVIEW_LEN, -1 ) ) {
            send_message( MSG_PLAY_SYSTEM_TONE | MSG_2P, tone_sms_ascending_id,
               TONE_SMS_ASCENDING_FLAGS );
         }
         
         send_message(MSG_REQUEST_QUIT);
         break;

      case MSG_DISPLAY_MENU_VALUE:
         // Display current WPM value directly in the menu
         own_print_menu_value( (const nokstr_t*)strcat( init_wpm_buffer(), " WPM" ) );
         break;
   }
   return msg;
}

/**************************************************************************************/

