#ifndef MAIN_H
#define MAIN_H

/*****************************************************************************************
 *
 * main.h
 * Copyright (c) 2010 NuukiaWorld
 *
 *  This file is part of "Morse tone".
 *
 *  "Network database" is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  "Network database" is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with "Morse tone".  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Version    Date          Author             Log
 *  --------------------------------------------------------------------------------------
 *  1.0        04.10.2010    NuukiaWorld        Initial Release
 *
 ****************************************************************************************/

#include <nokix/all.h>

/**************************************************************************************/

/* Define 32-bit custom types that are efficient for ARM7 registers.
   Use inside functions and in function prototypes when there is no
   need for truncation to a specific number of bits!
*/
typedef  unsigned int   char_t;        // Use instead of char
typedef  unsigned int   bool_t;        // Use instead of bool

/**************************************************************************************/

#define  TONE_LEN                   504   // Bytes to allocate for the actual tone commands
#define  TONE_LEN_LONGEST_CODE      22    // Max. tone bytes per one code

#define  TONE_SMS_ASCENDING_FLAGS   0xF1        // play_tone() flags used for "Ascending" SMS tone

/**************************************************************************************/

//extern   rexx_uint      confid_ticks_per_unit;
//extern   rexx_uint      tone_sms_ascending_params;
//extern   rexx_uint      tone_sms_ascending_id;
//extern   rexx_uint      tone_sms_ascending_note;

/* Pack data from the REXX script in more compact form */
extern   const struct {
   unsigned int   confid_ticks_per_unit;
   unsigned int   tone_sms_ascending_params;
   unsigned char  tone_sms_ascending_id;
   unsigned char  tone_sms_ascending_note;
} rexx_data;
#define  confid_ticks_per_unit      (rexx_data.confid_ticks_per_unit)
#define  tone_sms_ascending_params  (rexx_data.tone_sms_ascending_params)
#define  tone_sms_ascending_id      (rexx_data.tone_sms_ascending_id)
#define  tone_sms_ascending_note    (rexx_data.tone_sms_ascending_note)

extern   const struct dialog        dialog_wpm;
extern   const unsigned short       morse_table[];

/**************************************************************************************/

extern   bool_t   build_morse_tone( const unsigned char *text, unsigned int len, int skip );

/**************************************************************************************/

#endif /* MAIN_H */

